Struct irc::proto::message::Tag
[−]
[src]
pub struct Tag(pub String, pub Option<String>);
A message tag as defined by IRCv3.2. It consists of a tag key, and an optional value for the tag. Each message can contain a number of tags (in the string format, they are separated by semicolons). Tags are used to add extended information to a message under IRCv3.